@@ -3,14 +3,13 @@
 from . import metadata
 from .corpus.corpus_index import CorpusSourceIndex, ICorpusSourceItem
 from .corpus.iterate import ProtocolSegment, ProtocolSegmentIterator
-from .corpus.parlaclarin import pretokenize
 from .dehyphenation import SwedishDehyphenator
 from .dispatch import DispatchItem, SegmentMerger, create_grouping_hashcoder
 from .interface import ParlaClarinError, Protocol, SegmentLevel, Speech, Utterance
+from .preprocess import dedent, dehyphen, pretokenize
 from .to_speech import MergerFactory, MergeStrategyType, to_speeches
 from .utility import (
     compose,
-    dedent,
     deprecated,
     dget,
     dotget,
@@ -37,12 +36,14 @@ from .utility import (
     touch,
     ts_data_path,
     unlink,
+    xml_escape,
 )
 from .workflows import compute_term_frequencies, extract_corpus_tags, extract_corpus_text
 from .workflows.tag import (
     ITagger,
     ITaggerFactory,
     TaggedDocument,
+    TaggerProvider,
     TaggerRegistry,
     tag_protocol,
     tag_protocol_xml,
