@@ -1,6 +1,6 @@
 # type: ignore
 
-from .convert import ProtocolConverter, convert_protocol, dehyphen, pretokenize
+from .convert import ProtocolConverter, convert_protocol
 from .iterate import XmlProtocolSegmentIterator, XmlUntangleSegmentIterator
 from .parse import ProtocolMapper
 from .tf import TermFrequencyCounter
