@@ -3,17 +3,21 @@ from __future__ import annotations
 import abc
 import contextlib
 import csv
+import functools
+import gzip
 import hashlib
 import re
+import sys
+import zipfile
 from dataclasses import dataclass, field
 from enum import Enum
-from io import StringIO
+from io import StringIO, TextIOWrapper
 from typing import Any, Callable, Literal, Mapping, Optional, Union
 
 import pandas as pd
 from pandas.io import json
 
-from .utility import flatten, merge_csv_strings, strip_extensions
+from .utility import flatten, merge_csv_strings, strip_csv_header, strip_extensions, xml_escape
 
 # pylint: disable=too-many-arguments, no-member
 
@@ -57,6 +61,7 @@ class SegmentLevel(str, Enum):
     Speech = 'speech'
     Utterance = 'utterance'
     Paragraph = 'paragraph'
+    Sentence = 'sentence'
 
 
 class ContentType(str, Enum):
@@ -126,6 +131,18 @@ class SpeakerNote:
 MISSING_SPEAKER_NOTE: SpeakerNote = SpeakerNote(MISSING_SPEAKER_NOTE_ID, "")
 
 
+def vrt_exporter(func):
+    @functools.wraps(func)
+    def exporter(self, *tags, **kwargs):
+        keys: set[str] = {e.value for e in SegmentLevel}
+        if any(tag not in keys for tag in tags):
+            raise ValueError(f"Unknown tag: {tags}")
+
+        return func(self, *tags, **kwargs)
+
+    return exporter
+
+
 class Utterance:
     """Represents an utterance in the ParlaClarin XML file"""
 
@@ -182,6 +199,26 @@ class Utterance:
     def to_dict(self) -> dict:
         return UtteranceHelper.to_dict(self)
 
+    @vrt_exporter
+    def to_vrt(self, *tags: tuple[str]) -> str:
+        if not tags:
+            return xml_escape(strip_csv_header(self.annotation))
+
+        if 'sentence' in tags or 'paragraph' in tags:
+            # TODO: Tagged data frames must contain sentence/paragraph markers
+            # 1) Frame has a sentence/paragraph id column
+            # 2) Or sentence or paragraph markers are included in the tagged text on separate lines
+            raise NotImplementedError("Export to VRT with sentence/paragraph structural tags is not implemented yet.")
+
+        vrt_str: str = xml_escape(strip_csv_header(self.annotation))
+
+        if 'utterance' in tags:
+            vrt_str = (
+                f'<utterance id="{self.u_id}" page="{self.page_number}" who="{self.who}">\n{vrt_str}</utterance>\n'
+            )
+
+        return vrt_str
+
 
 class UtteranceHelper:
     CSV_OPTS = dict(
@@ -240,6 +277,11 @@ class UtteranceHelper:
             df: pd.DataFrame = pd.DataFrame(UtteranceHelper.to_dicts(utterances)).set_index('u_id')
         return df
 
+    @staticmethod
+    def to_vrt(utterances: list[Utterance], structural_tags: str = "") -> str:
+        """Convert list of utterances to a VRT string. Return VRT string."""
+        return '\n'.join(u.to_vrt(structural_tags) for u in utterances)
+
     @staticmethod
     def to_csv(utterances: list[Utterance]) -> str:
         """Convert list of utterances to a CSV string. Return CSV string."""
@@ -379,6 +421,26 @@ class Speech(UtteranceMixIn):
         self.utterances.append(item)
         return self
 
+    @vrt_exporter
+    def to_vrt(self, *tags: tuple[str]) -> str:
+        if tags is None:
+            return xml_escape(strip_csv_header(self.tagged_text))
+        vrt_str: str = '\n'.join(u.to_vrt(*tags) for u in self.utterances)
+        if 'speech' in tags:
+            vrt_str: str = (
+                '<speech '
+                f'id="{self.speech_id}" '
+                f'title="{self.document_name}" '
+                f'who="{self.who}" '
+                f'date="{self.speech_date}" '
+                f'page="{self.page_number}"'
+                '>\n'
+                f'{vrt_str}\n'
+                '</speech>'
+            )
+
+        return vrt_str
+
 
 class Protocol(UtteranceMixIn, IProtocol):
     """Entity that represents a ParlaCLARIN document."""
@@ -418,6 +480,76 @@ class Protocol(UtteranceMixIn, IProtocol):
     def get_speaker_notes(self) -> dict[str, str]:
         return self.speaker_notes
 
+    @vrt_exporter
+    def to_vrt(self, *tags: tuple[str], merge_strategy: str = "chain_consecutive_unknowns") -> str:
+        """Export protocol to VRT format with optional structural tags."""
+
+        """Local import do avoid circular dependency"""
+        from . import to_speech as mu  # pylint: disable=import-outside-toplevel
+
+        if tags is None:
+            return xml_escape(strip_csv_header(self.tagged_text))
+
+        vrt_str: str = ''
+        if 'speech' in tags:
+            speeches: list[Speech] = mu.to_speeches(protocol=self, merge_strategy=merge_strategy)
+            vrt_str: str = '\n'.join(s.to_vrt(*tags) for s in speeches)
+        else:
+            vrt_str: str = '\n'.join(u.to_vrt(*tags) for u in self.utterances)
+
+        if 'protocol' in tags:
+            vrt_str: str = f'<protocol title="{self.name}" date="{self.date}">\n{vrt_str}\n</protocol>'
+
+        return vrt_str
+
+    @classmethod
+    def to_vrts(
+        cls,
+        protocols: list["Protocol"],
+        *tags: tuple[str],
+        output: None | str = None,
+        outer_tag: str = None,
+        **outer_tag_attribs,
+    ) -> str:
+        """Export multiple protocols to VRT format with optional structural tags."""
+
+        if isinstance(output, str) and output.endswith("zip"):
+            if outer_tag:
+                raise ValueError("Cannot write to zip file with outer tag")
+
+            with zipfile.ZipFile(output, 'w') as zink:
+                for p in protocols:
+                    zink.writestr(f"{p.name}.vrt", p.to_vrt(*tags))
+                return None
+
+        with _open_output(output) as zink:
+            if outer_tag:
+                zink.write(_xml_start_tag(outer_tag, **outer_tag_attribs) + '\n')
+            for p in protocols:
+                zink.write(p.to_vrt(*tags))
+                zink.write('\n')
+            if outer_tag:
+                zink.write(f'</{outer_tag}>')
+            if isinstance(zink, StringIO):
+                return zink.getvalue()
+            return None
+
+
+def _open_output(output: str) -> TextIOWrapper:
+    if output == '-':
+        return contextlib.nullcontext(sys.stdout)
+    if output is None:
+        return StringIO('', newline='')
+    if output.endswith('.gz'):
+        return gzip.open(output, 'wt', encoding="utf8")
+    return open(output, 'w', encoding="utf8")
+
+
+def _xml_start_tag(tag: str, **attribs) -> str:
+    """Generate XML open tag with optional attributes."""
+    attrib_str: str = " ".join((f"{k}=\"{v}\"" for k, v in attribs.items()))
+    return f"<{tag} {attrib_str}>"
+
 
 class IProtocolParser(abc.ABC):
     @staticmethod
