@@ -1,5 +1,5 @@
 from .extract_tags import extract_corpus_tags
 from .extract_text import extract_corpus_text
 from .subset_corpus import subset_corpus_and_metadata
-from .tag import tag_protocol, tag_protocol_xml, tag_protocols
+from .tag import TaggerProvider, tag_protocol, tag_protocol_xml, tag_protocols
 from .tf import compute_term_frequencies
